INTRO
=====

This directory holds the proposals of non-trivial changes to senlin. We host
them here to avoid the potential headaches in managing yet another project,
say `senlin-specs`. When the needs rise up for a dedicated project for
proposals, we can create such a project and migrate things here.


DIRECTORY LAYOUT
================

Proposals will be put into this directory during review. After being reviewed,
it will be migrated into the `rejected` subdirectory or the `approved`
subdirectory respectively.


rejected
--------

A subdirectory for proposals that were rejected.


approved
--------

A subdirectory for proposals that were approved.
